require "rails_helper"

RSpec.feature "Creating Articles" do

  before do
    @john = User.create!(email: 'john@example.com', password: 'password')
    login_as(@john)
  end

  scenario "A User creates an Article" do
    visit "/"

    click_link "New Article"

    fill_in "Title", with: "New Blog Article"
    fill_in "Body", with: "Lorem ipsum"

    click_button "Create Article"

    expect(Article.last.user).to eq(@john)
    expect(page).to have_content("Article has been created")
    expect(page).to have_content("Created by: #{@john.email}")
    expect(page.current_path).to eq(articles_path)
  end

  scenario "A User fails to creates a new Article" do
    visit "/"

    click_link "New Article"

    fill_in "Title", with: ""
    fill_in "Body", with: ""

    click_button "Create Article"

    expect(page).to have_content("Article has not been created")
    expect(page).to have_content("Title can't be blank")
    expect(page).to have_content("Body can't be blank")
  end

end
